<% if (typeof(hypothesis) === "object") { %>
<script type="application/json" class="js-hypothesis-config">
<%= JSON.stringify(hypothesis, undefined, 2) %>
</script>
<% } %>
<script async src="https://hypothes.is/embed.js"></script>

