$wnd.rstudio.runAsyncCallback3("function $jq(a){this.a=a}\nfunction akq(a){this.a=a}\nfunction jkq(a){this.a=a}\nfunction rBf(a,b){var c;for(c=0;c<a.q.a.length;c++){if(q6d(a.q,c).zNc==b){pHf(a.t,gBe(c));break}}}\nfunction Xjq(a){var b;b=Yjq(a,(Ujq(),Tjq).v7b(),a.b,_rp(a.c.c));b||Yjq(a,Tjq.r7b(),a.a,Zrp(a.c.c))}\nfunction Zjq(a,b){this.c=a;this.b=_rp(a.c).XXb();this.a=Zrp(a.c).XXb();xi(b,new $jq(this),cE?cE:(cE=new xB))}\nfunction Vjq(a,b,c){var d;d=Jcq(a.b.a);wBf(d,Q_p(V2j((MKh(),LKh).a)));!!b&&rBf(d,b);CBf(d,c);Nnf(d,true);new Zjq(a,d);(iSh()||!!$wnd.remoteDesktop)&&qSh()}\nfunction Yjq(a,b,c,d){if(fO(c)!==fO(d.XXb())&&fO(d.Zs())!==fO(d.XXb())){Z1e(2,(Ujq(),Tjq).s7b(),Tjq.t7b(b,d.XXb(),d.Zs()),new akq(a),true);return true}else{return false}}\nfunction fkq(a){try{if(a.c<0)return;!a.a.a&&(a.a.a=Jsq(a.a.b.a));switch(a.c){case 1:Vjq(a.a.a,null,true);break;case 2:Vjq(a.a.a,a.b[0],Mze(a.b[1]));}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].ln()}}\nvar _GB='LaTeX typesetting',aHB='Project Option Unchanged',bHB='You changed the global option for ',cHB=', however the current project is still configured to use ',dHB='weaving Rnw files';qNd(2993,1,{},Zjq);var Oec=hAe(2993);qNd(2994,1,hyy,$jq);_.wo=function _jq(a){Xjq(this.a)};var Mec=hAe(2994);qNd(2995,1,eEy,akq);_.ln=function bkq(){U8e(this.a.c.a.kh)};var Nec=hAe(2995);qNd(637,1,G8y);_.jn=function ikq(){fkq((new jkq(this)).a)};qNd(3060,1,EAy,jkq);_.ln=function kkq(){fkq(this.a)};var Pec=hAe(3060);qNd(4138,1,xTA);_.r7b=function gpq(){return _GB};_.s7b=function hpq(){return aHB};_.t7b=function ipq(a,b,c){return bHB+a+cAy+b+cHB+c+'.\\\\n\\\\nDo you want to edit the options for the current project as well?'};_.v7b=function kpq(){return dHB};qNd(4139,1,xTA);_.r7b=function spq(){return _GB};_.s7b=function tpq(){return aHB};_.t7b=function upq(a,b,c){return bHB+a+cAy+b+cHB+c+'.\\n\\nDo you want to edit the options for the current project as well?'};_.v7b=function wpq(){return dHB};qNd(4137,1,xTA);_.r7b=function Epq(){return 'Mise en page LaTeX'};_.s7b=function Fpq(){return 'Option du projet inchang\\xE9e'};_.t7b=function Gpq(a,b,c){return \"Vous avez chang\\xE9 l'option globale de \"+a+' en '+b+', mais le projet actuel est toujours configur\\xE9 pour utiliser '+c+'.\\n\\nVoulez-vous \\xE9galement modifier les options du projet actuel ?'};_.v7b=function Ipq(){return 'Tisse le fichiers Rnw'};xky(hm)(3);\n//# sourceURL=rstudio-3.js\n")
