<% if (items) { %>
<ul class="navbar-nav navbar-nav-scroll <%- align === 'start' ? 'me-auto' : 'ms-auto' %>">
<% for(const item of items) { %>
  <% partial('navitem.ejs', { item, align }) %> 
<% } %>
</ul>
<% } %>