$wnd.rstudio.runAsyncCallback16("function oMt(a){this.a=a}\nfunction GJt(a,b){this.a=a;this.b=b;nmf.call(this)}\nfunction iJt(a,b){a.a=b;CLt(a.p,eJt(a,null),a.a.file_path)}\nfunction kJt(a,b){b.slide_index==0&&Jpq(a.p);a.a=b;CLt(a.p,eJt(a,null),a.a.file_path)}\nfunction rJt(a){moh(cJt.Xpc(),poe());V1h(a.c,new Q3h,false)}\nfunction fJt(a){var b;b=zzi(new Azi(0,cJt.Tpc()));vum(a.n,new GJt(a,b))}\nfunction vum(a,b){yzm(a,Epz,'close_presentation_pane',new wL,b)}\nfunction qJt(a){var b;a.J.d7b();!!a.a&&a.a.active&&(b=njf(Oh(a.p.d).contentWindow),!(!TBe(oEy,b)&&!TBe('javascript:void(0)',b)))&&iJt(a,a.a)}\nfunction kMt(a){var b,c;try{if(a.c<0)return;if(!a.a.a){a.a.a=$Mt(a.a.b.a);Miq(a.a,a.a.a)}switch(a.c){case 1:fJt((c=a.a.a,a.b[0],c));break;case 2:kJt(a.a.a,a.b[0]);break;case 3:a.a.a.J.b7b();break;case 4:a.a.a.J.c7b();break;case 5:qJt(a.a.a);break;case 6:rJt((b=a.a.a,a.b[0],b));break;case 7:a.a.a.J.e7b();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].ln()}}\nvar eKB='Closing Presentation...',fKB='Opening Presentation...';qNd(8207,33,{},GJt);_.AA=function IJt(a){var b;V1h((b=this,a,b).a.c,new Q3h,false)};_.zA=function HJt(a){Pyi(this.b,a.a?a.a.c:a.d)};var rRc=hAe(8207);qNd(9072,1,UfB);_.Tpc=function lKt(){return eKB};_.Xpc=function qKt(){return fKB};qNd(9070,1,UfB);_.Tpc=function DKt(){return eKB};_.Xpc=function IKt(){return fKB};qNd(9071,1,UfB);_.Tpc=function VKt(){return 'Fermeture de la pr\\xE9sentation...'};_.Xpc=function $Kt(){return 'Ouvrir la pr\\xE9sentation...'};qNd(465,1,G8y);_.jn=function nMt(){kMt((new oMt(this)).a)};qNd(7477,1,EAy,oMt);_.ln=function pMt(){kMt(this.a)};var TRc=hAe(7477);xky(hm)(16);\n//# sourceURL=rstudio-16.js\n")
